import { assertEquals } from '@std/assert'
import { describe, it } from '@std/testing/bdd'

import { QueryEvents } from './QueryEvents.ts'
import { ActivityResult } from '../adapters/jasd/types/appapi.dto.types.ts'
import { LocalTimedEvent } from '../adapters/jasd/tests/fixtures.ts'

describe('QueryEvents', () => {
  it('can make sense of an empty response', async () => {
    const jasdGatewayMock = {
      fetchActivities() {
        return Promise.resolve({ events: [], totalCount: 0 })
      },
    }

    const sut = new QueryEvents(jasdGatewayMock, console)

    const result = await sut.execute({ offset: 0, limit: 1, localOnly: false })

    assertEquals(result, {
      data: [],
      totalResults: 0,
    })
  })

  it('can return a jsad event', async () => {
    const jasdGatewayMock = {
      fetchActivities(): Promise<{ events: ActivityResult[]; totalCount: number }> {
        return Promise.resolve({
          events: [LocalTimedEvent as ActivityResult],
          totalCount: 1,
        })
      },
    }

    const sut = new QueryEvents(jasdGatewayMock, console)

    const result = await sut.execute({ offset: 0, limit: 1, localOnly: false })

    assertEquals(result, {
      data: [
        {
          id: '4610',
          title: 'RealTimedEvent',
          organisationName: 'Allerweltskino e.V.',
          startDate: '2025-03-26T00:00:00+01:00',
          endDate: '2025-03-26T00:00:00+01:00',
          location: {
            city: 'Köln',
            street: 'Bahnhofstr.',
            streetNo: '41',
            zipCode: '50674',
          },
          isRemote: false,
          imageUrl: 'https://gemeinschaftswerk-nachhaltigkeit.de/app/api/v1/files/activities/act5.jpg',
          eventDetails: {
            description:
              '<p>Jeden Dienstag (bis auf eine Sommer- und Winterpause) zeigt der Verein Allerweltskino e.V. im Kölner Filmtheater Off Broadway einen Nachhaltigkeitsfilm. Das Programm ist im Internet abrufbar (siehe Kasten rechts).</p>',
            externalLink: 'https://www.allerweltskino.de',
            meetingLink: 'https://www.allerweltskino.de',
          },
        },
      ],
      totalResults: 1,
    })
  })
})
